Viewing Partial Trees
Date: 07 12, 2001 12:25:51 PM

Viewing Partial Trees from Text Files

You can select a specific part of text in an analyzed file and view the parse tree for that line of text only. This is helpful when you want to see how the rule matcher worked on a particular part of text.

To view a partial parse tree:

1. In the Text Tab, double click on the processed text to open it in the Workspace.

2. Highlight the text.

3. Right-click and select View > Tree of Selected. The parse tree for the highlighted text opens in the Workspace.

## See Also

Viewing Parse Trees

Viewing Concept Trees

Viewing Intermediate Trees

Viewing Parse Tree Matches

Viewing Final Trees